#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['kanina']

package_data = \
{'': ['*'], 'kanina': ['dist/*']}

setup(name='kanina',
      version='0.0.1',
      description='An simple calculator package',
      author='Henrikas',
      author_email='henrikass@yahoo.com',
      url=None,
      packages=packages,
      package_data=package_data,
      python_requires='>=3.8',
     )
